summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/storage/imymoneyserialize.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/storage/imymoneyserialize.h')
-rw-r--r--kmymoney2/mymoney/storage/imymoneyserialize.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/mymoney/storage/imymoneyserialize.h b/kmymoney2/mymoney/storage/imymoneyserialize.h
index c900687..dc37edd 100644
--- a/kmymoney2/mymoney/storage/imymoneyserialize.h
+++ b/kmymoney2/mymoney/storage/imymoneyserialize.h
@@ -194,12 +194,12 @@ public:
/**
* This method is used to add one account as sub-ordinate to another
- * (tqparent) account. The objects that are passed will be modified
+ * (parent) account. The objects that are passed will be modified
* accordingly.
*
* An exception will be thrown upon error conditions.
*
* @param tqparent tqparent account the account should be added to
* @param account the account to be added
*
* @deprecated This method is only provided as long as we provide
@@ -207,7 +207,7 @@ public:
* this compatability mode this method will disappear from
* this interface!
*/
- virtual void addAccount(MyMoneyAccount& tqparent, MyMoneyAccount& account) = 0;
+ virtual void addAccount(MyMoneyAccount& parent, MyMoneyAccount& account) = 0;
/**
* This method is used to create a new payee
@@ -194,12 +194,12 @@ public:
* An exception will be thrown upon error conditions.
*
- * @param tqparent tqparent account the account should be added to
+ * @param parent parent account the account should be added to
* @param account the account to be added
*